Method: Assets#get_asset_variation
- Defined in:
- lib/user/content/assets.rb
#get_asset_variation(id) ⇒ Object
Get asset variation.
Get variation of an asset.
Parameters
- id
-
(Integer) Asset variation id. #TODO: Research if is an asset id or an variation id
Example
@data = @mints_user.get_asset_sizes(2)
285 286 287 288 289 |
# File 'lib/user/content/assets.rb', line 285 def get_asset_variation(id) #FIXME: Id 1 and 4: Trying to get property 'path' of non-object maybe json conversion is bad #FIXME: Id 2 and 3: File not found at path maybe doesnt exist return @client.raw("get", "/content/assets/variation/#{id}") end |