Method: Assets#get_assets

Defined in:
lib/user/content/assets.rb

#get_assets(options = nil, use_post = true) ⇒ Object

Assets

Get assets.

Get a collection of assets.

Parameters

options

(Hash) – List of Resource Collection Options shown above can be used as parameter.

use_post

(Boolean) – Variable to determine if the request is by ‘post’ or ‘get’ functions.

First Example

@data = @mints_user.get_assets

Second Example

options = {
  "fields": "id, title"
}
@data = @mints_user.get_assets(options)

Third Example

options = {
  "fields": "id, title"
}
@data = @mints_user.get_assets(options, true)


28
29
30
# File 'lib/user/content/assets.rb', line 28

def get_assets(options = nil, use_post = true)
    return get_query_results("/content/assets", options, use_post)
end