Method: Attributes#get_sub_attributes
- Defined in:
- lib/user/config/attributes.rb
#get_sub_attributes(options) ⇒ Object
Get sub attributes.
Get sub attributes with a slug.
Parameters
- options
-
(Hash) – List of Resource Collection Options shown above can be used as parameter.
Example
23 24 25 |
# File 'lib/user/config/attributes.rb', line 23 def get_sub_attributes() #TODO: Test, this method has been added recently return @client.raw("get", "/config/attributes/sub-attributes", ) end |