Method: Mints::Contact#get_orders

Defined in:
lib/contact.rb

#get_orders(options = nil, use_post = true) ⇒ Object

Get Orders.

Get a collection of orders.

Parameters

options

(Hash) – List of Resource Collection Options shown above can be used as parameter.

use_post

(Boolean) – Variable to determine if the request is by ‘post’ or ‘get’ functions.

First Example

@data = @mints_pub.get_orders

Second Example

options = { "fields": "title" }
@data = @mints_pub.get_orders(options)

Third Example

options = { "fields": "title" }
@data = @mints_pub.get_orders(options, false)


566
567
568
569
570
571
572
# File 'lib/contact.rb', line 566

def get_orders(options = nil, use_post = true)
  if use_post
    return @client.raw("post", "/ecommerce/orders/query", options, nil, @contact_v1_url)
  else
    return @client.raw("get", "/ecommerce/orders", options, nil, @contact_v1_url)
  end
end