Class: Mints::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/client.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(host, api_key, scope = nil, session_token = nil, contact_token_id = nil, visit_id = nil, debug = false) ⇒ Client

Returns a new instance of Client.



18
19
20
21
22
23
24
25
26
27
# File 'lib/client.rb', line 18

def initialize(host, api_key, scope = nil, session_token = nil, contact_token_id = nil, visit_id = nil, debug = false)
  @host = host
  @api_key = api_key
  @session_token = session_token
  @contact_token_id = contact_token_id
  @visit_id = visit_id
  @debug = debug

  self.set_scope(scope)
end

Dynamic Method Handling

This class handles dynamic methods through the method_missing method

#method_missing(name, *args, &block) ⇒ Object



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/client.rb', line 130

def method_missing(name, *args, &block)
  name.to_s.include?('__') ? separator = '__' : separator = '_'
  # split the name to identify their elements
  name_splitted = name.to_s.split(separator)
  # count the elements
  name_len = name_splitted.size
  # the action always be the first element
  action = name_splitted.first
  raise 'NoActionError' unless %w[get create post update put delete destroy verify_response_status].include?(action)
  # the object always be the last element
  object = separator == '__' ? name_splitted.last.gsub('_', '-') : name_splitted.last
  # get intermediate url elements
  route_array = []
  (name_len - 1).times do |n|
    next if n === 0 or n === name_len - 1

    n = name_splitted[n]
    self.replacements.each do |object|
      n = n.gsub(object[:old_value], object[:new_value])
    end
    route_array.push n
  end
  route = route_array.join('/')

  slug = nil
  response = nil
  uri = Addressable::URI.new

  if action == 'get'
    if args.first.class == Hash
      uri.query_values = args.first
    elsif args.first.class == String or Integer
      slug = args.first
      uri.query_values = args[1]
    end

    url = self.get_url(route, object, uri, slug)
    response = self.send("#{@scope}_#{action}", url, nil, compatibility_options)
  elsif action == 'post' or action == 'create'
    if args[1].class == Hash
      uri.query_values = args[1]
    end

    url = self.get_url(route, object, uri, slug)
    action = 'post'
    data = args[0]
    response = self.send("#{@scope}_#{action}", url, { data: data }, compatibility_options)
  elsif action == 'put' or action == 'update'
    if args.first.class == String or Integer
      slug = args.first
      uri.query_values = args[2]
    end

    url = self.get_url(route, object, uri, slug)
    action = 'put'
    data = args[1]
    response = self.send("#{@scope}_#{action}", "#{url}", { data: data }, compatibility_options)
  end

  verify_response_status(response, config['sdk']['ignore_http_errors'])

  response ? JSON.parse(response.body) : nil
end

Instance Attribute Details

#api_keyObject (readonly)

Returns the value of attribute api_key.



12
13
14
# File 'lib/client.rb', line 12

def api_key
  @api_key
end

#base_urlObject (readonly)

Returns the value of attribute base_url.



14
15
16
# File 'lib/client.rb', line 14

def base_url
  @base_url
end

#contact_token_idObject

Returns the value of attribute contact_token_id.



16
17
18
# File 'lib/client.rb', line 16

def contact_token_id
  @contact_token_id
end

#hostObject (readonly)

Returns the value of attribute host.



11
12
13
# File 'lib/client.rb', line 11

def host
  @host
end

#scopeObject (readonly)

Returns the value of attribute scope.



13
14
15
# File 'lib/client.rb', line 13

def scope
  @scope
end

#session_tokenObject

Returns the value of attribute session_token.



15
16
17
# File 'lib/client.rb', line 15

def session_token
  @session_token
end

Instance Method Details

#contact_get(url, headers = nil, compatibility_options) ⇒ Object

Start contact context



244
245
246
247
248
# File 'lib/client.rb', line 244

def contact_get(url, headers = nil, compatibility_options)
  h = set_headers(compatibility_options, headers)

  self.http_get(url, h)
end

#contact_post(url, data, compatibility_options) ⇒ Object



250
251
252
253
254
# File 'lib/client.rb', line 250

def contact_post(url, data, compatibility_options)
  headers = set_headers(compatibility_options)

  self.http_post(url, headers, data)
end

#contact_put(url, data, compatibility_options) ⇒ Object



256
257
258
259
260
# File 'lib/client.rb', line 256

def contact_put(url, data, compatibility_options)
  headers = set_headers(compatibility_options)

  self.http_put(url, headers, data)
end

#get_url(route, object, uri, slug = nil) ⇒ Object



194
195
196
197
198
199
200
# File 'lib/client.rb', line 194

def get_url(route, object, uri, slug = nil)
  if slug
    "#{@host}#{@base_url}/#{route}/#{object}/#{slug}#{uri}"
  else
    "#{@host}#{@base_url}/#{route}/#{object}#{uri}"
  end
end

#http_delete(url, headers = nil, data = nil) ⇒ Object

Simple HTTP DELETE



239
240
241
# File 'lib/client.rb', line 239

def http_delete(url, headers = nil, data = nil)
  HTTParty.delete(url, headers: headers, body: data)
end

#http_get(url, headers = nil) ⇒ Object

HTTP CLIENTS ###### Simple HTTP GET



224
225
226
# File 'lib/client.rb', line 224

def http_get(url, headers = nil)
  HTTParty.get(url, headers: headers)
end

#http_post(url, headers = nil, data = nil) ⇒ Object

Simple HTTP POST



229
230
231
# File 'lib/client.rb', line 229

def http_post(url, headers = nil, data = nil)
  HTTParty.post(url, headers: headers, body: data)
end

#http_put(url, headers = nil, data = nil) ⇒ Object

Simple HTTP PUT



234
235
236
# File 'lib/client.rb', line 234

def http_put(url, headers = nil, data = nil)
  HTTParty.put(url, headers: headers, body: data)
end

#public_get(url, headers = nil, compatibility_options) ⇒ Object

End User Context



283
284
285
# File 'lib/client.rb', line 283

def public_get(url, headers = nil, compatibility_options)
  self.http_get(url, set_headers(compatibility_options, headers))
end

#public_post(url, headers = nil, data, compatibility_options) ⇒ Object



287
288
289
# File 'lib/client.rb', line 287

def public_post(url, headers = nil, data, compatibility_options)
  self.http_post(url, set_headers(compatibility_options, headers), data)
end

#public_put(url, headers = nil, data, compatibility_options) ⇒ Object



291
292
293
# File 'lib/client.rb', line 291

def public_put(url, headers = nil, data, compatibility_options)
  self.http_put(url, set_headers(compatibility_options, headers), data)
end

#raw(action, url, options = nil, data = nil, base_url = nil, compatibility_options = {}, only_tracking = false) ⇒ Object



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/client.rb', line 29

def raw(action, url, options = nil, data = nil, base_url = nil, compatibility_options = {}, only_tracking = false)
  compatibility_options = {} if compatibility_options.nil?

  base_url = @base_url unless base_url
  uri = ''

  if options&.class == Hash
    need_encoding = %w[jfilters afilters rfilters]
    found_options_with_encoding = options.keys.select { |key| need_encoding.include?(key.to_s.downcase) and options[key]&.class == Hash }

    found_options_with_encoding.each do |key|
      options[key] = CGI::escape(Base64.encode64(options[key].to_json))
    end

    uri = Addressable::URI.new
    uri.query_values = options
  end

  full_url = "#{@host}#{base_url}#{url}#{uri}"
  response = nil

  template = ERB.new File.new("#{Rails.root}/mints_config.yml.erb").read
  config = YAML.safe_load template.result(binding)
  result_from_cache = false

  if action === 'get'
    url_need_cache = false

    if config['redis_cache']['use_cache']
      config['redis_cache']['groups'].each do |group|
        group['urls'].each do |url|
          if full_url.match url
            time = group['time']
            url_need_cache = true
            @redis_server = Redis.new(
              host: config['redis_cache']['redis_host'],
              port: config['redis_cache']['redis_port'] ? config['redis_cache']['redis_port'] : 6379,
              db: config['redis_cache']['redis_db'] ? config['redis_cache']['redis_db'] : 1
            )
            redis_response = @redis_server.get(full_url)

            if redis_response
              response = redis_response
              result_from_cache = true

              if only_tracking
                # headers = { 'Only-Tracking' => 'true' }
                #when is already in redis notify to California to register the object usage
                #cali_response = self.send("#{@scope}_#{action}", full_url, headers, compatibility_options)
              end
            else
              response = self.send("#{@scope}_#{action}", full_url, nil, compatibility_options)
              @redis_server.setex(full_url, time, response)
            end
            break
          end
        end

        break if url_need_cache
      end
    end

    unless url_need_cache
      response = self.send("#{@scope}_#{action}", full_url, nil, compatibility_options)
    end

  elsif action === 'create' or action === 'post'
    action = 'post'
    response = self.send("#{@scope}_#{action}", full_url, data, compatibility_options)
  elsif action === 'put' or action === 'patch' or action === 'update'
    action = 'put'
    response = self.send("#{@scope}_#{action}", full_url, data, compatibility_options)
  elsif action === 'delete' or action === 'destroy'
    action = 'delete'
    response = self.send("#{@scope}_#{action}", full_url, data, compatibility_options)
  end

  verify_response_status(response, config['sdk']['ignore_http_errors'])

  begin
    if result_from_cache
      if @debug
        puts "Method: #{action} \nURL: #{url} \nOptions: #{options&.to_json} \nOnly tracking: #{only_tracking} \nResponse from: REDIS"
        puts "Data: #{data.to_json}" if data
      end

      return JSON.parse(response)
    else

      if @debug
        puts "Method: #{action} \nURL: #{url} \nOptions: #{options&.to_json} \nOnly tracking: #{only_tracking} \nResponse from: CALI"
        puts "Data: #{data.to_json}" if data
      end

      return JSON.parse(response&.body)
    end
  rescue
    return response
  end
end

#replacementsObject



202
203
204
205
206
207
208
# File 'lib/client.rb', line 202

def replacements
  [
    { old_value: '_', new_value: '-' },
    { old_value: 'people', new_value: 'crm' },
    { old_value: 'store', new_value: 'ecommerce' }
  ]
end

#set_headers(compatibility_options, headers = nil) ⇒ Object



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/client.rb', line 295

def set_headers(compatibility_options, headers = nil)
  h = {
    'Accept' => 'application/json',
    'ApiKey' => @api_key
  }
  h['Content-Type'] = 'application/json' unless compatibility_options['no_content_type']
  h['ContactToken'] = @contact_token_id if @contact_token_id
  h['Visit-Id'] = @visit_id if @visit_id
  h['Authorization'] = "Bearer #{@session_token}" if @session_token

  if headers
    headers.each do |k, v|
      h[k] = v
    end
  end

  h
end

#set_scope(scope) ⇒ Object



210
211
212
213
214
215
216
217
218
219
220
# File 'lib/client.rb', line 210

def set_scope(scope)
  @scope = scope
  if scope === 'public' or scope === 'contact'
    @base_url = '/api/v1'
  elsif scope === 'user'
    @base_url = '/api/user/v1'
  else
    @scope = 'public'
    @base_url = '/api/v1'
  end
end

#user_delete(url, data, compatibility_options) ⇒ Object



277
278
279
# File 'lib/client.rb', line 277

def user_delete(url, data, compatibility_options)
  self.http_delete(url, set_headers(compatibility_options), data)
end

#user_get(url, headers = nil, compatibility_options) ⇒ Object

Start User context



263
264
265
266
267
# File 'lib/client.rb', line 263

def user_get(url, headers = nil, compatibility_options)
  h = set_headers(compatibility_options, headers)

  self.http_get(url, h)
end

#user_post(url, data, compatibility_options) ⇒ Object



269
270
271
# File 'lib/client.rb', line 269

def user_post(url, data, compatibility_options)
  self.http_post(url, set_headers(compatibility_options), data)
end

#user_put(url, data, compatibility_options) ⇒ Object



273
274
275
# File 'lib/client.rb', line 273

def user_put(url, data, compatibility_options)
  self.http_put(url, set_headers(compatibility_options), data)
end

#verify_response_status(response, ignore_http_errors) ⇒ Object



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/client.rb', line 314

def verify_response_status(response, ignore_http_errors)
  # Verify if the response is cached
  unless response.kind_of? String
    # Raise an error if response code is not 2xx
    http_status = response&.response&.code&.to_i || 500
    is_success = (http_status >= 200 and http_status < 300)

    if !is_success and !ignore_http_errors
      title = "Request failed with status #{http_status}"
      detail = response&.response&.message || 'Unknown error'

      puts "Error detected: #{http_status}" if @debug
      error_class = Errors::DynamicError.new(self, title, detail, http_status, response&.parsed_response)

      raise error_class if @debug

      raise error_class.error
    end
  end
end