Method: MintsHelper#get_query_results

Defined in:
lib/mints_helper.rb

#get_query_results(url, options = nil, use_post = true) ⇒ Object

Get query results.

Method used to give the options to make a ‘post’ or ‘get’ request.

Parameters

url

(String) – Url to make the request.

options

(Hash) – List of Resource collection Options shown above can be used as parameter.

use_post

(Boolean) – Variable to determine if the request is by ‘post’ or ‘get’ functions.



11
12
13
14
15
16
17
# File 'lib/mints_helper.rb', line 11

def get_query_results(url, options = nil, use_post = true)
    if use_post
    return @client.raw("post", "#{url}/query", options)
    else
    return @client.raw("get", url, options)
    end
end